#include "map_win.h"
#include <set>

bool MapWin::closeIfEscapeIsPressed(GdkEventKey* e)
{
  if(e->keyval==GDK_Escape)
  {
    hide();
  }
  return true;
}

MapWin::MapWin(const std::string& title, MapStorage & mapst, GraphDisplayerCanvas & grdispc, NewMapWin & newmapwin):gdc(grdispc),ms(mapst), nmw(newmapwin)
{
  set_title(title);
  set_default_size(200, 50);

  signal_key_press_event().connect(sigc::mem_fun(*this, &MapWin::closeIfEscapeIsPressed));

  e_combo_array=new MapSelector * [EDGE_PROPERTY_NUM];

  table=new Gtk::Table(EDGE_PROPERTY_NUM, 1, false);

  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
  {
    e_combo_array[i]=new MapSelector(gdc, ms, nmw, i, true);

    (*table).attach((*(e_combo_array[i])),0,1,i,i+1,Gtk::SHRINK,Gtk::SHRINK,10,3);
  }

  vbox.pack_start(*(new Gtk::Label("Edge properties")));

  vbox.pack_start(*table);

  vbox.pack_start(*(new Gtk::HSeparator));

  n_combo_array=new MapSelector * [NODE_PROPERTY_NUM];

  table=new Gtk::Table(NODE_PROPERTY_NUM, 1, false);

  for(int i=0;i<NODE_PROPERTY_NUM;i++)
  {
    n_combo_array[i]=new MapSelector(gdc, ms, nmw, i, false);

    (*table).attach((*(n_combo_array[i])),0,1,i,i+1,Gtk::SHRINK,Gtk::SHRINK,10,3);
  }

  add(vbox);

  vbox.pack_start(*(new Gtk::Label("Node properties")));

  vbox.pack_start(*table);

  show_all_children();

}

void MapWin::update()
{
  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
  {
    e_combo_array[i]->update_list();
  }

  for(int i=0;i<NODE_PROPERTY_NUM;i++)
  {
    n_combo_array[i]->update_list();
  }
}


void MapWin::updateNode(Node node)
{
  for(int i=0;i<NODE_PROPERTY_NUM;i++)
    {
      n_combo_array[i]->update(node);
    }
}

void MapWin::updateEdge(Edge edge)
{
  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
    {
      e_combo_array[i]->update(edge);
    }
}

void MapWin::registerNewEdgeMap(std::string newmapname)
{
  for(int i=0;i<EDGE_PROPERTY_NUM;i++)
  {
    //filling in combo box with choices
    e_combo_array[i]->append_text((Glib::ustring)newmapname);
  }
  //setting text property for the new map
  e_combo_array[N_TEXT]->set_active_text((Glib::ustring)newmapname);
}

void MapWin::registerNewNodeMap(std::string newmapname)
{
  for(int i=0;i<NODE_PROPERTY_NUM;i++)
  {
    //filling in combo box with choices
    n_combo_array[i]->append_text((Glib::ustring)newmapname);
  }
  //setting text property for the new map
  n_combo_array[N_TEXT]->set_active_text((Glib::ustring)newmapname);
}
